@@ -211,7 +211,7 @@ def run():
 
         vm = VersionManager()
         if vm.has_updated():
-            print('发现新版本，开始更新')
+            print(f'发现新版本，开始更新({VersionManager.m_current_version})')
             vm.start_update()
             print('更新完成')
 
